Package 'shinysocial'

Title: Social Media Modules for 'shiny'
Description: Standardized, clean modules for collecting, displaying, and using social media information in 'shiny' apps.
Authors: Jon Harmon [aut, cre, cph] (ORCID: <https://orcid.org/0000-0003-4781-4346>)
Maintainer: Jon Harmon <[email protected]>
License: MIT + file LICENSE
Version: 0.0.0.9000
Built: 2026-05-21 09:41:47 UTC
Source: https://github.com/shinyworks/shinysocial

Help Index


Collect social media contact information

Description

A shiny module to collect and normalize a user's social media contact information.

Usage

social_contacts_ui(id, twitter = TRUE, linkedin = TRUE)

social_contacts_server(id)

Arguments

id

The unique identifier of the module. This value must match between the ui and the server.

twitter, linkedin

Logical; whether to include the given site in the ui. At least one of these values must be TRUE.

Value

A shiny module ui, or the normalized contacts from one.