Collect social media contact information
Description
A shiny module to collect and normalize a user's social media contact
information.
Usage
social_contacts_ui(id, twitter = TRUE, linkedin = TRUE)
social_contacts_server(id)
social_contacts_ui(id, twitter = TRUE, linkedin = TRUE)
social_contacts_server(id)
Arguments
id |
The unique identifier of the module. This value must match between
the ui and the server.
|
, linkedin
|
Logical; whether to include the given site in the ui.
At least one of these values must be TRUE.
|
Value
A shiny module ui, or the normalized contacts from one.
Collect social media contact information
Description
A shiny module to collect and normalize a user's social media contact information.
Usage
Arguments
idThe unique identifier of the module. This value must match between the ui and the server.
twitter,linkedinLogical; whether to include the given site in the ui. At least one of these values must be
TRUE.Value
A shiny module ui, or the normalized contacts from one.